# NornFlow

Nornflow is still in prototype phase.
The idea is for it to become both a tiny CLI-wrapper around Nornir, as well as a ansible-like orchestration tool, giving the user the ability to comfortably manage network automation workflows through YAML files.